# pdb2reaction add-elem-info

```
pdb2reaction ver. 0.2.1.dev116+gff86b942a

Usage: cli add-elem-info [OPTIONS]

  Add/repair element columns (77–78) in a PDB using Biopython.

Options:
  --help-advanced   Show all options (including advanced settings) and exit.
  -i, --input FILE  Input PDB filepath.  [required]
  -o, --out FILE    Output PDB filepath (default: replace ".pdb" with
                    "_add_elem.pdb"; when provided, --overwrite is ignored).
  -h, --help        Show this message and exit.
```
